@@ -1,14 +1,70 @@
 package OMA::Download::DRM::REL::XML;
 use strict;
-
 BEGIN {
-    use 5.8.7;
     use MIME::Base64;
+	use OMA::Download::DRM::REL;
+	push @OMA::Download::DRM::REL::XML::ISA, 'OMA::Download::DRM::REL';
 }
+=head1 NAME
 
+OMA::Download::DRM::REL::XML - XML representation of the OMA DRM REL 1.0
+
+=head1 DESCRIPTION
+
+XML representation of the Open Mobile Alliance Digital Rights Management Rights Expression Language 1.0
+
+=head1 SYNOPSIS
+
+  use OMA::Download::DRM::REL::XML;
+
+=head1 CONSTRUCTOR
+
+  my $rel=OMA::Download::DRM::REL::XML->new(%args);
+
+=head1 PROPERTIES
+
+=head2 mime
+
+Returns the XML rights object MIME type
+
+  print $rel->mime;
+
+=cut
+sub mime      { 'application/vnd.oma.drm.rights+xml' }
+
+
+=head2 extension
+
+Returns the XML rights object extension
+
+  print $rel->extension;
+
+=cut
+sub extension { '.dr' }
 
 ### Class init -----------------------------------------------------------------
-sub init {
+
+
+=head1 METHODS
+
+
+=head2 packit
+
+Packs data using XML format
+
+  print $rel->packit;
+
+=cut
+sub packit {
+    my ($self)=@_;
+    my $res='';
+    $res.='<?xml version="1.0" encoding="utf-8"?>'."\n";   # WBXML Version Number (1.3)
+    $res.='<!DOCTYPE o-ex:rights PUBLIC "-//OMA//DTD REL 1.0//EN" "http://www.oma.org/dtd/dr">'."\n";  # Public Identifier (~//OMA//DTD REL 1.0//EN)
+    return $res.'<o-ex:rights xmlns:o-ex="http://odrl.net/1.1/ODRL-EX" xmlns:o-dd="http://odrl.net/1.1/ODRL-DD" xmlns:ds="http://www.w3.org/2000/09/xmldsig#/">'."\n".$self->_packin."\n".'</o-ex:rights>';
+}
+
+#--- Support routines ----------------------------------------------------------
+sub _init {
     my ($self)=@_;
     $self->{'element_tokens'} = {
         'rights'      => 'o-ex:rights',
@@ -36,27 +92,6 @@ sub init {
 	}
     return 1;
 }
-
-
-
-### Properties -----------------------------------------------------------------
-sub mime      { 'application/vnd.oma.drm.rights+xml' }
-sub extension { '.dr' }
-
-### Methods --------------------------------------------------------------------
-sub packit {
-    my ($self)=@_;
-    my $res='';
-    $res.='<?xml version="1.0" encoding="utf-8"?>'."\n";   # WBXML Version Number (1.3)
-    $res.='<!DOCTYPE o-ex:rights PUBLIC "-//OMA//DTD REL 1.0//EN" "http://www.oma.org/dtd/dr">'."\n";  # Public Identifier (~//OMA//DTD REL 1.0//EN)
-    
-    my $content=$self->packin;
-
-    # rights element attributes
-    return $res.'<o-ex:rights xmlns:o-ex="http://odrl.net/1.1/ODRL-EX" xmlns:o-dd="http://odrl.net/1.1/ODRL-DD" xmlns:ds="http://www.w3.org/2000/09/xmldsig#/">'."\n".$content."\n".'</o-ex:rights>';
-}
-
-#--- Support routines ----------------------------------------------------------
 sub _in_element {
     my ($self, $element, $content, $is_root)=@_;
     die "Unknown element token $element" unless $self->{element_tokens}{$element};
@@ -69,24 +104,13 @@ sub _in_element {
     return $res;
 }
 sub _in_string {
-    my ($self, $string)=@_;
-    return $string;
+    return $_[1];
 }
 sub _in_opaque {
-    my ($self,$data)=@_;
-    return $data;
+    return $_[1];
 }
 1;
 __END__
-
-=head1 NAME
-
-OMA::Download::DRM::REL::XML - XML representation of the OMA DRM REL 1.0
-
-=head1 DESCRIPTION
-
-XML representation of the Open Mobile Alliance Digital Rights Management Rights Expression Language 1.0
-
 =head1 SEE ALSO
 
 OMA::Download::DRM::REL
@@ -97,8 +121,8 @@ Bernard Nauwelaerts, E<lt>bpgn@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Bernard Nauwelaerts
+Copyright (C) 2006 by Bernard Nauwelaerts.
 
-Released under GPL licence
+Released under the GPL.
 
 =cut
\ No newline at end of file
